@@ -220,13 +220,12 @@ const BaseButton = GObject.registerClass({
 
         super._init({
             style_class: 'window-button',
-            x_fill: true,
-            y_fill: true,
             can_focus: true,
+            x_expand: true,
             button_mask: St.ButtonMask.ONE | St.ButtonMask.THREE,
         });
 
-        this.connect('allocation-changed',
+        this.connect('notify::allocation',
             this._updateIconGeometry.bind(this));
         this.connect('clicked', this._onClicked.bind(this));
         this.connect('destroy', this._onDestroy.bind(this));
@@ -491,8 +490,6 @@ class AppButton extends BaseButton {
 
         this._singleWindowTitle = new St.Bin({
             x_expand: true,
-            y_fill: true,
-            x_align: St.Align.START,
         });
         stack.add_actor(this._singleWindowTitle);
 
@@ -940,10 +937,7 @@ class WindowList extends St.Widget {
         let button = new AppButton(app, this._perMonitor, this._monitor.index);
         this._settings.bind('display-all-workspaces',
             button, 'ignore-workspace', Gio.SettingsBindFlags.GET);
-        this._windowList.layout_manager.pack(button,
-            true, true, true,
-            Clutter.BoxAlignment.START,
-            Clutter.BoxAlignment.START);
+        this._windowList.add_child(button);
     }
 
     _removeApp(app) {
@@ -970,10 +964,7 @@ class WindowList extends St.Widget {
         let button = new WindowButton(win, this._perMonitor, this._monitor.index);
         this._settings.bind('display-all-workspaces',
             button, 'ignore-workspace', Gio.SettingsBindFlags.GET);
-        this._windowList.layout_manager.pack(button,
-            true, true, true,
-            Clutter.BoxAlignment.START,
-            Clutter.BoxAlignment.START);
+        this._windowList.add_child(button);
     }
 
     _onWindowRemoved(ws, win) {
